Package: wyz.code.rdoc
Type: Package
Title: Wizardry Code Offensive Programming R Documentation
Version: 1.1.19
Author: Fabien Gelineau <neonira@gmail.com>
Maintainer: Fabien Gelineau <neonira@gmail.com>
Description: Allows to generate on-demand or by batch, any R documentation file,
    whatever is kind, data, function, class or package. It populates
    documentation sections, either automatically or by considering
    your input. Input code could be standard R code or offensive programming code. 
    Documentation content completeness depends on the type of code you use. With
    offensive programming code, expect generated documentation to be fully 
    completed, from a format and content point of view. With some standard R 
    code, you will have to activate post processing to fill-in any section that 
    requires complements. Produced manual page validity is automatically tested 
    against R documentation compliance rules. Documentation language 
    proficiency, wording style, and phrasal adjustments remains your job. 
Encoding: UTF-8
LazyData: true
License: GPL-3
Depends: R (>= 4.0)
Imports: methods, data.table (>= 1.11.8), tidyr,
        wyz.code.offensiveProgramming (>= 1.1.22), stringr (>= 1.4.0),
        R6 (>= 2.4.0), crayon (>= 1.3.4), digest (>= 0.6.23)
Suggests: testthat, knitr, rmarkdown
RoxygenNote: 7.0.2
VignetteBuilder: knitr
URL: https://neonira.github.io/offensiveProgrammingBook_v1.2.2/
NeedsCompilation: no
Packaged: 2021-10-06 06:25:08 UTC; fabien
Repository: CRAN
Date/Publication: 2021-10-06 07:00:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:54:59 UTC; unix
