\name{WeirdNames-\%*\%}
\alias{WeirdNames$\%*\%}
\alias{\%*\%}
\title{Method WeirdNames$\%*\%}
\description{
Use this method to \%*\%.
}
\usage{
\%*\%(x_, y_)
}
\arguments{
\item{x_}{An unconstrained vector of variable type objects}
\item{y_}{An unconstrained vector of variable type objects}
}
\section{Information}{
\subsection{Environment fields}{
◆ \bold{self} environment
}
\subsection{Environment methods}{
■ \bold{\%*\%}\cr■ \bold{f}
}
\subsection{offensive programming - semantic naming}{
Function name compliance is \code{FALSE}.

Function parameter-names compliance is \code{TRUE}.

Function parameter-names compliance is \code{TRUE}.

Function parameter-names semantic naming compliance is \code{TRUE}.

Function parameter-names semantic naming compliance is \code{TRUE}.
}
\subsection{offensive programming - function return types}{
▶ Function return type is not instrumented.
}
\subsection{offensive programming - test case definitions}{
▶ Test case definition is not instrumented.
}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\seealso{
Class \code{\link{ProcessingContext}} and class \code{\link{InputContext}}.
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
