\name{completeManualPage}
\alias{completeManualPage}
\title{Function completeManualPage}
\usage{
completeManualPage(filename_s_1, contentToAdd_l)
}
\arguments{
\item{filename_s_1}{A single string value}
\item{contentToAdd_l}{An unconstrained list}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_3

PHASING ▶ RUN

INTENT  ▶ QUALITY_CONTROL
}
