\name{auditDocumentationFiles}
\alias{auditDocumentationFiles}
\title{Function auditDocumentationFiles}
\usage{
auditDocumentationFiles(folder_s)
}
\arguments{
\item{folder_s}{An unconstrained vector of string values}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_1

PHASING ▶ BUILD

INTENT  ▶ QUALITY_CONTROL
}
