\name{producePackageLink}
\alias{producePackageLink}
\title{Function producePackageLink}
\usage{
producePackageLink(packageName_s_1, topicName_s_1)
}
\arguments{
\item{packageName_s_1}{A single string value}
\item{topicName_s_1}{A single string value}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_3

PHASING ▶ BUILD

INTENT  ▶ PARTS_BUILDING
}
