\name{verifyDocumentationFile}
\alias{verifyDocumentationFile}
\title{Function verifyDocumentationFile}
\usage{
verifyDocumentationFile(filename_s_1)
}
\arguments{
\item{filename_s_1}{A single string value}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_1

PHASING ▶ RUN

INTENT  ▶ QUALITY_CONTROL
}
