\name{generateParagraphCR}
\alias{generateParagraphCR}
\title{Function generateParagraphCR}
\description{
Data set to be used as example for demo purpose.
}
\usage{
generateParagraphCR(..., addFinalSeparator_b_1 = FALSE)
}
\arguments{
\item{...}{additional arguments.}
\item{addFinalSeparator_b_1}{A single boolean value}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{function}
\concept{documentation generation}
\encoding{UTF-8}
\source{
Data set generated by NEONIRA
}
\section{Classification}{
STRATUM ▶ LAYER_1

PHASING ▶ BUILD

INTENT  ▶ PARTS_BUILDING
}
