\name{packageFunctionsInformation}
\alias{packageFunctionsInformation}
\title{Function packageFunctionsInformation}
\usage{
packageFunctionsInformation()
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_3

PHASING ▶ RUN

INTENT  ▶ FEEDBACK
}
