\name{warning}
\alias{warning}
\title{Function warning}
\description{bla bla bla}
\usage{
warning(..., na.rm = FALSE)
}
\arguments{
\item{...}{bla blo}
\item{na.omit}{bli blu}
\method{lsd}{z}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
