\name{ManualPageBuilder-buildManualPage}
\alias{ManualPageBuilder$buildManualPage}
\alias{buildManualPage}
\title{Method ManualPageBuilder$buildManualPage}
\description{
Use this method to build manual page.
}
\usage{
buildManualPage()
}
\section{Information}{
\subsection{Environment fields}{
◆ \bold{colorizer} list\cr◆ \bold{generationContext_o_1} environment\cr◆ \bold{inputContext_o_1} environment\cr◆ \bold{processingContext_o_1} environment\cr◆ \bold{self} environment\cr◆ \bold{strategy} list
}
\subsection{Environment methods}{
■ \bold{assembleManualPage}\cr■ \bold{buildManualPage}\cr■ \bold{documentContent}\cr■ \bold{getStrategy}\cr■ \bold{interpretResults}
}
\subsection{offensive programming - semantic naming}{
Function name compliance is \code{TRUE}.

Function parameter-names compliance is \code{TRUE}.

Function parameter-names semantic naming compliance is \code{TRUE}.
}
\subsection{offensive programming - function return types}{
▶ Function return type is not instrumented.
}
\subsection{offensive programming - test case definitions}{
▶ Test case definition is not instrumented.
}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\seealso{
Class \code{\link{InputContext}} class \code{\link{ProcessingContext}} class \code{\link{GenerationContext}} and class \code{\link{ManualPageBuilder}}.
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
