\name{append}
\alias{append}
\title{Function append}
\description{
A fake description
}
\usage{
append(x, values, after = length(x))
}
\arguments{
\item{x}{XXX_001}
\item{values}{XXX_002}
\item{after}{XXX_003}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\name{append}
\alias{append}
\title{Function append}
\description{

A fake description

}
\usage{

append(x, values, after = length(x))

}
\arguments{

\item{x}{XXX_001}
\item{values}{XXX_002}
\item{after}{XXX_003}

}
\author{

\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}

}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\title{a patched title}
\concept{zorg}
\details{
details
}
