\name{WeirdNames-class}
\docType{class}
\alias{WeirdNames-class}
\alias{WeirdNames}
\title{Class WeirdNames}
\description{
Environment class WeirdNames.
}
\usage{
WeirdNames()
}
\value{
An object instance of class \code{WeirdNames}.
}
\section{Information}{
\subsection{Environment fields}{
◆ \bold{self} environment
}
\subsection{Environment methods}{
■ \bold{\%*\%}\cr■ \bold{f}
}
\subsection{offensive programming - semantic naming}{
Class name compliance is \code{TRUE}.
}
\subsection{offensive programming - function return types}{
Class owns no function return type instrumentation.
}
\subsection{offensive programming - test case definitions}{
Class owns no test case definitions.
}
\subsection{offensive programming - examples}{
wn <- WeirdNames()
}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\seealso{
Class \code{\link{ProcessingContext}} and class \code{\link{InputContext}}.
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
