\name{generateSection}
\alias{generateSection}
\title{Function generateSection}
\usage{
generateSection(sectionName_s_1, content_s)
}
\arguments{
\item{sectionName_s_1}{A single string value}
\item{content_s}{An unconstrained vector of string values}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_1

PHASING ▶ BUILD

INTENT  ▶ PARTS_BUILDING
}
