\name{rdocKeywords}
\alias{rdocKeywords}
\title{Function rdocKeywords}
\usage{
rdocKeywords(asList_b_1 = FALSE)
}
\arguments{
\item{asList_b_1}{A single boolean value}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ CORE

PHASING ▶ RUN

INTENT  ▶ FEEDBACK
}
