\name{sum}
\alias{sum}
\title{Function sum}
\description{
A fake description
}
\usage{
sum(..., na.rm = FALSE)
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
