\name{getStandardSectionNames}
\alias{getStandardSectionNames}
\title{Function getStandardSectionNames}
\usage{
getStandardSectionNames(sort_b_1 = FALSE)
}
\arguments{
\item{sort_b_1}{A single boolean value}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_1

PHASING ▶ BUILD

INTENT  ▶ CONTENT_GENERATION
}
