\name{beautify}
\alias{beautify}
\title{Function beautify}
\usage{
beautify()
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_2

PHASING ▶ BUILD

INTENT  ▶ PARTS_BUILDING
}
