\name{generateReference}
\alias{generateReference}
\title{Function generateReference}
\usage{
generateReference(data_l)
}
\arguments{
\item{data_l}{An unconstrained list}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_1

PHASING ▶ BUILD

INTENT  ▶ PARTS_BUILDING
}
