\name{identifyReplacementVariables}
\alias{identifyReplacementVariables}
\title{Function identifyReplacementVariables}
\usage{
identifyReplacementVariables(filename_s)
}
\arguments{
\item{filename_s}{An unconstrained vector of string values}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_3

PHASING ▶ RUN

INTENT  ▶ FEEDBACK
}
