\name{computeDocumentationStatistics}
\alias{computeDocumentationStatistics}
\title{Function computeDocumentationStatistics}
\usage{
computeDocumentationStatistics(filename_s_1, maxLineLength_pi_1 = 100L)
}
\arguments{
\item{filename_s_1}{A single string value}
\item{maxLineLength_pi_1}{A single positive integer value}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_3

PHASING ▶ RUN

INTENT  ▶ STATISTICS
}
