\name{convertExamples}
\alias{convertExamples}
\title{Function convertExamples}
\usage{
convertExamples(examples_l, captureOutput_b_1n = TRUE, mode_s = c(NA, "donttest", "dontrun", "dontshow")[1])
}
\arguments{
\item{examples_l}{An unconstrained list}
\item{captureOutput_b_1n}{XXX_001}
\item{mode_s}{An unconstrained vector of string values}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_3

PHASING ▶ RUN

INTENT  ▶ PARTS_ASSEMBLY
}
