\name{generateOptionSexpr}
\alias{generateOptionSexpr}
\title{Function generateOptionSexpr}
\usage{
generateOptionSexpr(options_s_1, topicName_s_1, escapeBraces_b_1 = FALSE)
}
\arguments{
\item{options_s_1}{A single string value}
\item{topicName_s_1}{A single string value}
\item{escapeBraces_b_1}{A single boolean value}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_1

PHASING ▶ BUILD

INTENT  ▶ PARTS_BUILDING
}
