\name{opfun}
\alias{opfun}
\title{Function opfun}
\description{
A fake description
}
\usage{
opfun(x_l, x_s, x_b_1)
}
\arguments{
\item{x_l}{An unconstrained list}
\item{x_s}{An unconstrained vector of string values}
\item{x_b_1}{A single boolean value}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\encoding{UTF-8}
