\name{generateEnc}
\alias{generateEnc}
\title{Function generateEnc}
\description{
Data set to be used as example for demo purpose.
}
\usage{
generateEnc(entries_l)
}
\arguments{
\item{entries_l}{An unconstrained list}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{function}
\concept{documentation generation}
\encoding{UTF-8}
\source{
Data set generated by NEONIRA
}
\section{Classification}{
STRATUM ▶ LAYER_1

PHASING ▶ BUILD

INTENT  ▶ PARTS_BUILDING
}
