\name{interpretResults}
\alias{interpretResults}
\title{Function interpretResults}
\usage{
interpretResults(manualPageGenerationResults_l)
}
\arguments{
\item{manualPageGenerationResults_l}{An unconstrained list}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_3

PHASING ▶ RUN

INTENT  ▶ QUALITY_CONTROL
}
