\name{wyz.code.rdoc-package}
\docType{package}
\alias{wyz.code.rdoc-package}
\alias{wyz.code.rdoc}
\title{\packageTitle{wyz.code.rdoc}}
\description{
\packageDescription{wyz.code.rdoc}
}
\usage{
library(wyz.code.rdoc)
}
\details{
The DESCRIPTION file
\packageDESCRIPTION{
wyz.code.rdoc
}
\packageIndices{
wyz.code.rdoc
}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
