\name{error}
\name{error}
\alias{error}
\title{Function error}
\description{
A fake description
}
\usage{
error(..., na.rm = FALSE)
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-9}
