\name{ProcessingContext-verifyExtraneous}
\alias{ProcessingContext$verifyExtraneous}
\alias{verifyExtraneous}
\title{Method ProcessingContext$verifyExtraneous}
\description{
Use this method to verify extraneous.
}
\usage{
verifyExtraneous(extraneous_l)
}
\arguments{
\item{extraneous_l}{An unconstrained list}
}
\section{Information}{
\subsection{Environment fields}{
◆ \bold{extraneous_l} list\cr◆ \bold{postProcessing_l} list\cr◆ \bold{self} environment
}
\subsection{Environment methods}{
■ \bold{verifyExtraneous}\cr■ \bold{verifyPostProcessing}
}
\subsection{offensive programming - semantic naming}{
Function name compliance is \code{TRUE}.

Function parameter-names compliance is \code{TRUE}.

Function parameter-names semantic naming compliance is \code{TRUE}.
}
\subsection{offensive programming - function return types}{
▶ Function return type is not instrumented.
}
\subsection{offensive programming - test case definitions}{
▶ Test case definition is not instrumented.
}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
