\name{generateTable}
\alias{generateTable}
\title{Function generateTable}
\usage{
generateTable(content_dt, alignement_s_1 = NA_character_, numberRows_b_1 = FALSE)
}
\arguments{
\item{content_dt}{An unconstrained vector of data.table objects}
\item{alignement_s_1}{A single string value}
\item{numberRows_b_1}{A single boolean value}
}
\author{
\packageAuthor{wyz.code.rdoc}

Maintainer: \packageMaintainer{wyz.code.rdoc}
}
\keyword{documentation}
\concept{documentation generation}
\encoding{UTF-8}
\section{Classification}{
STRATUM ▶ LAYER_1

PHASING ▶ BUILD

INTENT  ▶ PARTS_BUILDING
}
